Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CertificateMaker ¶
type CertificateMaker interface {
// MakeCertificate returns a certificate for the given hostname. The
// hostname and IP address are both optional, but typically provide
// additional security.
MakeCertificate(ctx context.Context, hostname, ip string) (*pki.TLSConfigPEM, error)
}
CertificateMaker makes TLS certificates appropriate for a particular use case. We are agnostic as to how they are stored and distributed, their lifetime, or what fields are stored.
type NetworkConfig ¶
type Node ¶
type Node struct {
// Name is the node name, which may mean different things to different
// services. May also be the host name for some drivers. May also be
// resolvable with some drivers, though not necessarily by the cluster
// creating code.
Name string
Ports Ports
Host string
TLS *pki.TLSConfigPEM
}
A Node describes a service instance, typically a member or future member of a cluster. The Node may not yet exist. Multiple nodes of different types may map to the same host, e.g. a host might run both Consul and Nomad, and may use different TLS for each.
type Port ¶
type Port struct {
Number int
Type PortNetworkType
}
type PortNetworkType ¶
type PortNetworkType int
const TCPAndUDP PortNetworkType = 2
const TCPOnly PortNetworkType = 0
const UDPOnly PortNetworkType = 1
Directories
¶
| Path | Synopsis |
|---|---|
|
binaries fetches "binaries" from URLs, decompresses/extracts them if the URL points to an archive like a zip, and provides a path to the binary named after the package.
|
binaries fetches "binaries" from URLs, decompresses/extracts them if the URL points to an archive like a zip, and provides a path to the binary named after the package. |
|
cmd
|
|
|
get-binary
command
|
|
|
yurt-cluster
command
|
|
|
yurt-run
command
|
|
|
helper
|
|
Click to show internal directories.
Click to hide internal directories.